@@ -1,22 +1,17 @@
 import itertools
 from typing import List
-import numpy as np
+
 import matplotlib.pyplot as plt
+import numpy as np
 from mpl_toolkits.axes_grid1.inset_locator import inset_axes
-from yupi.graphics._style import (
-    LIGHT_YELLOW,
-    LIGHT_BLUE,
-    LIGHT_ORANGE,
-    GREEN,
-    LIGHT_GREEN,
-    RED,
-    YUPI_COLORS,
-    YUPI_LIGHT_COLORS,
-    _plot_basic_properties
-)
+from yupi.graphics._style import (GREEN, LIGHT_BLUE, LIGHT_GREEN, LIGHT_ORANGE,
+                                  LIGHT_YELLOW, RED, YUPI_COLORS,
+                                  YUPI_LIGHT_COLORS, _plot_basic_properties)
+
 
 def _validate_units(units):
-    return '' if units is None else f' [{units}]'
+    return "" if units is None else f" [{units}]"
+
 
 @_plot_basic_properties
 def plot_hist(values: np.ndarray, **kwargs):
@@ -29,16 +24,21 @@ def plot_hist(values: np.ndarray, **kwargs):
         Input values
     """
 
-    if 'color' not in kwargs:
-        kwargs['color'] = YUPI_LIGHT_COLORS[0]
-    if 'ec' not in kwargs:
-        kwargs['ec'] = (0,0,0,0.6)
+    if "color" not in kwargs:
+        kwargs["color"] = YUPI_LIGHT_COLORS[0]
+    if "ec" not in kwargs:
+        kwargs["ec"] = (0, 0, 0, 0.6)
     plt.hist(values, **kwargs)
 
+
 @_plot_basic_properties
-def plot_hists(values_list: List[np.ndarray], kwargs_list: List[dict] = None,
-               labels: List[str] = None, filled: bool = False,
-               **general_kwargs):
+def plot_hists(
+    values_list: List[np.ndarray],
+    kwargs_list: List[dict] = None,
+    labels: List[str] = None,
+    filled: bool = False,
+    **general_kwargs,
+):
     """
     Plot several histograms given a collection of values.
 
@@ -54,8 +54,9 @@ def plot_hists(values_list: List[np.ndarray], kwargs_list: List[dict] = None,
     """
 
     if kwargs_list and len(kwargs_list) != len(values_list):
-        raise ValueError("The length of 'kwargs_list' must be equals the "
-                         "length of 'values_list'")
+        raise ValueError(
+            "The length of 'kwargs_list' must be equals the " "length of 'values_list'"
+        )
 
     kwargs_list = [{}] * len(values_list)
 
@@ -69,27 +70,25 @@ def plot_hists(values_list: List[np.ndarray], kwargs_list: List[dict] = None,
         kwargs = kwargs if len(kwargs) != 0 else general_kwargs
         lw = 1.5
         if labels is not None:
-            kwargs['label'] = labels[i]
-        if 'histtype' in kwargs:
-            kwargs.pop('histtype')
-        if 'color' in kwargs:
-            color = kwargs['color']
-        if 'lw' in kwargs:
-            lw = kwargs['lw']
-        if 'alpha' not in kwargs:
-            kwargs['alpha'] = alpha
-        alpha = kwargs.pop('alpha', alpha)
+            kwargs["label"] = labels[i]
+        if "histtype" in kwargs:
+            kwargs.pop("histtype")
+        if "color" in kwargs:
+            color = kwargs["color"]
+        if "lw" in kwargs:
+            lw = kwargs["lw"]
+        if "alpha" not in kwargs:
+            kwargs["alpha"] = alpha
+        alpha = kwargs.pop("alpha", alpha)
 
-        plt.hist(vals, histtype='step', color=color, lw=lw, **kwargs)
+        plt.hist(vals, histtype="step", color=color, lw=lw, **kwargs)
 
         if filled:
-            kwargs.pop('label', None)
-            plt.hist(vals, histtype='stepfilled', color=color, alpha=alpha,
-                     **kwargs)
+            kwargs.pop("label", None)
+            plt.hist(vals, histtype="stepfilled", color=color, alpha=alpha, **kwargs)
 
 
-
-def plot_velocity_hist(v, show: bool = True, units: str = 'm/s', **kwargs):
+def plot_velocity_hist(v, show: bool = True, units: str = "m/s", **kwargs):
     """Plot a histogram of the array of velocities ``v``.
 
     Parameters
@@ -102,17 +101,17 @@ def plot_velocity_hist(v, show: bool = True, units: str = 'm/s', **kwargs):
         Velocity units. By default 'm/s'.
     """
 
-    if 'color' not in kwargs:
-        kwargs['color'] = LIGHT_YELLOW
+    if "color" not in kwargs:
+        kwargs["color"] = LIGHT_YELLOW
 
-    if 'density' in kwargs:
-        kwargs.pop('density')
+    if "density" in kwargs:
+        kwargs.pop("density")
 
     units = _validate_units(units)
 
-    plt.hist(v, ec=(0,0,0,0.6), density=True, **kwargs)
-    plt.xlabel(f'speed{units}')
-    plt.ylabel('pdf')
+    plt.hist(v, ec=(0, 0, 0, 0.6), density=True, **kwargs)
+    plt.xlabel(f"speed{units}")
+    plt.ylabel("pdf")
     plt.grid()
     plt.gca().set_axisbelow(True)
 
@@ -120,7 +119,7 @@ def plot_velocity_hist(v, show: bool = True, units: str = 'm/s', **kwargs):
         plt.show()
 
 
-def plot_angles_hist(ang, bins, show: bool = True, ax=None):
+def plot_angles_hist(ang, bins, show: bool = True, ax=None, **kwargs):
     """Plot a histogram of the array of angles ``ang``.
 
     Parameters
@@ -136,18 +135,31 @@ def plot_angles_hist(ang, bins, show: bool = True, ax=None):
     """
 
     if ax is None:
-        ax = plt.gca(projection='polar')
-    plt.hist(ang, bins, density=True, ec=(0,0,0,0.6), color=LIGHT_BLUE)
-    ax.set_theta_zero_location('N')
+        ax = plt.axes(projection="polar")
+    elif ax.name != "polar":
+        raise ValueError("The axes must be polar")
+    default_kwargs = {"color": LIGHT_BLUE, "ec": (0, 0, 0, 0.6), "density": True}
+    default_kwargs.update(kwargs)
+    plt.hist(ang, bins, **default_kwargs)
+    ax.set_theta_zero_location("N")
     ax.set_rlabel_position(135)
     ax.set_axisbelow(True)
-    plt.xlabel('turning angles pdf')
+    plt.xlabel("turning angles pdf")
     if show:
         plt.show()
 
 
-def plot_msd(msd, msd_std, dt, lag, x_units: str = 's', y_units: str = 'm^2/s',
-             show=True):
+def plot_msd(
+    msd,
+    msd_std,
+    dt,
+    lag,
+    x_units: str = "s",
+    y_units: str = "m^2/s",
+    show=True,
+    fill_color=LIGHT_ORANGE,
+    **kwargs,
+):
     """Plot Mean Square Displacement.
 
     Parameters
@@ -172,19 +184,29 @@ def plot_msd(msd, msd_std, dt, lag, x_units: str = 's', y_units: str = 'm^2/s',
     y_units = _validate_units(y_units)
 
     lag_t_msd = dt * np.arange(lag)
-    plt.plot(lag_t_msd, msd, color='.2')
+    default_kwargs = {"color": ".2"}
+    default_kwargs.update(kwargs)
+    plt.plot(lag_t_msd, msd, **default_kwargs)
     upper_bound = msd + msd_std
     lower_bound = msd - msd_std
-    plt.fill_between(lag_t_msd, upper_bound, lower_bound, color=LIGHT_ORANGE)
-    plt.xlabel(f'lag time{x_units}')
-    plt.ylabel(r'$\mathrm{msd \;' + y_units + '}$')
+    plt.fill_between(lag_t_msd, upper_bound, lower_bound, color=fill_color)
+    plt.xlabel(f"lag time{x_units}")
+    plt.ylabel(r"$\mathrm{msd \;" + y_units + "}$")
     plt.grid()
     if show:
         plt.show()
 
 
-def plot_kurtosis(kurtosis, dt=None, t_array=None, kurtosis_ref: float = None,
-                  units: str = 's', show=True):
+def plot_kurtosis(
+    kurtosis,
+    dt=None,
+    t_array=None,
+    kurtosis_ref: float = None,
+    units: str = "s",
+    show=True,
+    ref_color=LIGHT_GREEN,
+    **kwargs,
+):
     """Plot kurtosis.
 
     Parameters
@@ -206,27 +228,31 @@ def plot_kurtosis(kurtosis, dt=None, t_array=None, kurtosis_ref: float = None,
 
     units = _validate_units(units)
 
+    if "color" not in kwargs:
+        kwargs["color"] = GREEN
+
     if dt:
-        t_array = np.linspace(0, dt*len(kurtosis), len(kurtosis))
+        t_array = np.linspace(0, dt * len(kurtosis), len(kurtosis))
     if t_array is not None:
-        plt.plot(t_array, kurtosis, color=GREEN)
+        plt.plot(t_array, kurtosis, **kwargs)
 
         if kurtosis_ref is not None:
             bound_1 = kurtosis
-            bound_2 = [kurtosis_ref]*len(t_array)
-            plt.fill_between(t_array, bound_1, bound_2, color=LIGHT_GREEN)
-        plt.xlabel(f'time{units}')
+            bound_2 = [kurtosis_ref] * len(t_array)
+            plt.fill_between(t_array, bound_1, bound_2, color=ref_color)
+        plt.xlabel(f"time{units}")
     else:
-        plt.plot(kurtosis)
+        plt.plot(kurtosis, **kwargs)
 
-    plt.ylabel('kurtosis')
+    plt.ylabel("kurtosis")
     plt.grid()
     if show:
         plt.show()
 
 
-def plot_vacf(vacf, dt, lag, x_units: str = 's', y_units: str = '(m/s)^2',
-              show=True):
+def plot_vacf(
+    vacf, dt, lag, x_units: str = "s", y_units: str = "(m/s)^2", show=True, **kwargs
+):
     """Plot Velocity Autocorrelation Function.
 
     Parameters
@@ -251,25 +277,34 @@ def plot_vacf(vacf, dt, lag, x_units: str = 's', y_units: str = '(m/s)^2',
 
     lag_t_vacf = dt * np.arange(lag)
 
-    plt.plot(lag_t_vacf, vacf, '.', color=RED)
-    plt.xlabel(f'lag time{x_units}')
-    plt.ylabel(r'$\mathrm{vacf \;' + y_units + '}$')
+    if "color" not in kwargs:
+        kwargs["color"] = RED
+
+    plt.plot(lag_t_vacf, vacf, ".", **kwargs)
+    plt.xlabel(f"lag time{x_units}")
+    plt.ylabel(r"$\mathrm{vacf \;" + y_units + "}$")
     plt.grid()
 
     ax = plt.gca()
 
-    inset_axes(ax, width='60%', height='60%', bbox_to_anchor=(0, 0, 1, 1),
-               bbox_transform=ax.transAxes, loc='upper right')
+    inset_axes(
+        ax,
+        width="60%",
+        height="60%",
+        bbox_to_anchor=(0, 0, 1, 1),
+        bbox_transform=ax.transAxes,
+        loc="upper right",
+    )
 
-    plt.plot(lag_t_vacf, vacf, '.', color=RED)
-    plt.yscale('log')
+    plt.plot(lag_t_vacf, vacf, ".", **kwargs)
+    plt.yscale("log")
     plt.grid()
 
     if show:
         plt.show()
 
 
-def plot_psd(psd_mean, omega, psd_std=None, show=True):
+def plot_psd(psd_mean, omega, psd_std=None, show=True, **kwargs):
     """Plot the Power Spectral Density.
 
     Parameters
@@ -285,12 +320,13 @@ def plot_psd(psd_mean, omega, psd_std=None, show=True):
         If True, the plot is shown. By default True.
     """
 
-    plt.plot(omega, psd_mean, label='psd')
+    plt.plot(omega, psd_mean, label="psd", **kwargs)
     if psd_std is not None:
-        plt.fill_between(omega, psd_mean - psd_std, psd_mean + psd_std,
-            alpha=.3, label='psd_std')
-    plt.xscale('log')
-    plt.yscale('log')
+        plt.fill_between(
+            omega, psd_mean - psd_std, psd_mean + psd_std, alpha=0.3, label="psd_std"
+        )
+    plt.xscale("log")
+    plt.yscale("log")
     plt.legend()
     if show:
         plt.show()
