@@ -1,17 +1,17 @@
 import abc
-import cv2
 import logging
+import cv2
 import numpy as np
 
 
-def resize_frame(frame, scale=1):
+def _resize_frame(frame, scale=1):
     h, w = frame.shape[:2]
     w_, h_ = int(scale * w), int(scale * h)
     short_frame = cv2.resize(frame, (w_, h_), interpolation=cv2.INTER_AREA)
     return short_frame
 
 
-def change_colorspace(image, color_space):
+def _change_colorspace(image, color_space):
     if color_space == 'BGR':
         return image
     if color_space == 'GRAY':
@@ -136,96 +136,6 @@ class TrackingAlgorithm(metaclass=abc.ABCMeta):
         """
 
 
-# TODO: Fix this to emulate the previous Trackingalgorithm including this:
-# ant_ratio = ant_pixels / (roi_width * roi_heigh)
-# approximate ratio of the ant compare to the roi
-class IntensityMatching(TrackingAlgorithm):
-    """
-    Identifies the position of an object by thresholding the pixel
-    intensities of grayscale images.
-
-    Parameters
-    ----------
-    min_val : int, optional
-        Minimum value of pixel intensity to be considered as part of
-        the object, by default 0.
-    max_val : int, optional
-        Maximum value of pixel intensity to be considered as part of
-        the object, by default 255.
-    max_pixels : int, optional
-        If this parameter is passed, the algoritm will stop searching
-        for candidate pixels after reaching a count equal to this value,
-        by default None.
-    """
-
-    def __init__(self, min_val=0, max_val=255, max_pixels=None):
-        super().__init__()
-        self.min_val = min_val
-        self.max_val = max_val
-        self.max_pixels = max_pixels
-
-    def detect(self, frame, roi_bound=None, preprocessing=None):
-        """
-        Identifies the tracked object in the image ``frame``
-        by thresholding its grayscale version using the parameters
-        defined when the object was constructed.
-
-        Parameters
-        ----------
-        frame : np.ndarray
-            Image containing the object to be tracked
-        roi_bound : tuple, optional
-            Coordinates of the region of interest of the frame. The
-            expected format if a tuple with the form (xmin, xmax, ymin,
-            ymax). If passed the algorithm will crop this region of the
-            frame and will proceed only in this region, providing the
-            estimations refered to this region instead of the whole
-            image, by default None.
-        preprocessing : func
-            A function to be applied to the frame (Or cropped version
-            of it if roi_bound is passed) before detecting the object
-            on it, by default None.
-
-        Returns
-        -------
-        np.ndarray
-            A binary version of ``frame`` where elements with value
-            ``0`` indicate the absence of object and ``1`` the precense
-            of the object.
-        tuple
-            x, y coordinates of the centroid of the object in the image.
-        """
-
-        # Make a preprocessed (and copied) version of the frame
-        frame = self.preprocess(frame, roi_bound, preprocessing)
-
-        # Convert image to grayscale image
-        gray_image = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
-
-        if self.max_pixels:
-            # Obtain image histogram
-            ys = cv2.calcHist([gray_image], [0], None, [256], [0, 256],
-                              accumulate=True)
-
-            # Compute image total pixel count
-            x, y = gray_image.shape
-            total = x * y
-
-            # Compute an adaptative threshold according the ratio of
-            # Darkest pixels
-            max_threshold = self.max_val
-            for i in range(self.min_val, self.max_val):
-                if ys[i] > self.max_pixels:
-                    max_threshold = i
-                    break
-            self.max_val = max_threshold
-
-        mask = cv2.inRange(gray_image, self.min_val, self.max_val)
-        centroid = self.get_centroid(mask)
-        # Convert the grayscale image to binary image
-        return mask, centroid
-
-
 class ColorMatching(TrackingAlgorithm):
     """
     Identifies the position of an object by thresholding pixel
@@ -293,7 +203,7 @@ class ColorMatching(TrackingAlgorithm):
         frame = self.preprocess(frame, roi_bound, preprocessing)
 
         # Convert image to desired colorspace
-        copied_image = change_colorspace(frame, self.color_space)
+        copied_image = _change_colorspace(frame, self.color_space)
 
         mask = cv2.inRange(copied_image, self.lower_bound, self.upper_bound)
         centroid = self.get_centroid(mask)
