@@ -158,6 +158,8 @@ class Trajectory():
         if lengths.count(lengths[0]) != len(lengths):
             raise ValueError('All input arrays must have the same shape.')
 
+        self.__dt = dt
+        self.dt_mean = dt
         self.__t0 = t0
         self.__t = data[0]
         self.ang = data[1]
@@ -165,16 +167,16 @@ class Trajectory():
         self.lazy = lazy
 
         if self.__t is None:
-            self.dt = dt if dt is not None else 1.0
+            self.dt_mean = dt if dt is not None else 1.0
             self.dt_std = 0
             self.__v: Vector = self.r.delta / self.dt
         else:
-            self.dt = np.mean(np.array(self.__t.delta))
+            self.dt_mean = np.mean(np.array(self.__t.delta))
             self.dt_std = np.std(np.array(self.__t.delta))
             self.__v: Vector = (self.r.delta.T / self.__t.delta).T
 
         if t is not None and dt is not None:
-            if abs(self.dt - dt) > _threshold:
+            if abs(self.dt_mean - dt) > _threshold:
                 raise ValueError("You are giving 'dt' and 't' but 'dt' "
                                 "does not match with time values delta.")
             if abs(self.dt_std - 0) > _threshold:
@@ -186,6 +188,16 @@ class Trajectory():
 
         self.features = Features(self)
 
+    @property
+    def dt(self) -> float:
+        """
+        Returns the time between each position data value.
+
+        If the time data is not uniformly spaced it returns an
+        estimated value.
+        """
+        return self.dt_mean if self.__dt is None else self.__dt
+
     @property
     def uniformly_spaced(self) -> bool:
         """bool : True if the time data is uniformly spaced"""
@@ -350,7 +362,7 @@ class Trajectory():
         y = rad * np.sin(ang)
         self.r = Vector.create([x,y]).T
 
-    def rotate(self, angle: float):
+    def rotate2d(self, angle: float):
         """
         Rotates the trajectory around the center coordinates [0,0]
 
@@ -361,6 +373,41 @@ class Trajectory():
         """
         self.add_polar_offset(0, angle)
 
+    def rotate3d(self, angle: float, vector: Union[list, np.ndarray]):
+        """
+        Rotates the trajectory around a given vector.
+
+        Parameters
+        ----------
+        vector : Vector
+            Vector to rotate the trajectory around.
+        angle : float
+            Angle in radians to rotate the trajectory.
+
+        Raises
+        ------
+        TypeError
+            If the trajectory is not 3 dimensional.
+        """
+
+        if self.dim != 3:
+            raise TypeError('3D rotations can only be applied on 3 '
+                            'dimensional trajectories')
+
+        vec: Vector = Vector.create(vector)
+        if len(vec) != 3:
+            raise ValueError('The vector must have 3 components')
+
+        vec = vec / vec.norm
+        vx, vy, vz = vec[0], vec[1], vec[2]
+        c, s = np.cos(angle), np.sin(angle)
+
+        R = np.array([[vx*vx*(1-c)+c, vx*vy*(1-c)-vz*s, vx*vz*(1-c)+vy*s],
+                      [vx*vy*(1-c)+vz*s, vy*vy*(1-c)+c, vy*vz*(1-c)-vx*s],
+                      [vx*vz*(1-c)-vy*s, vy*vz*(1-c)+vx*s, vz*vz*(1-c)+c]])
+
+        self.r = Vector.create(np.dot(self.r, R))
+
     def copy(self) -> Trajectory:
         """
         Returns a copy of the trajectory.
@@ -530,7 +577,7 @@ class Trajectory():
         ang = None if self.ang is None else self.ang.T
         json_dict = {
             'id': self.traj_id,
-            'dt': self.dt,
+            'dt': self.__dt,
             'r': convert_to_list(self.r.T),
             'ang': convert_to_list(ang),
             't': convert_to_list(self.__t)
@@ -542,7 +589,7 @@ class Trajectory():
         with open(str(path), 'w', newline='') as traj_file:
             writer = csv.writer(traj_file, delimiter=',')
             ang_shape = 0 if self.ang is None else self.ang.shape[1]
-            writer.writerow([self.traj_id, self.dt, self.dim, ang_shape])
+            writer.writerow([self.traj_id, self.__dt, self.dim, ang_shape])
             for tp in self:
                 row = np.hstack(np.array([tp.r, tp.ang, tp.t], dtype=object))
                 writer.writerow(row)
